@@ -580,10 +580,9 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 cartaporte_mercancia.setAttribute('ValorMercancia', mercancia_data.get('ValorMercancia'))
                 cartaporte_mercancia.setAttribute('Moneda', mercancia_data.get('Moneda'))
 
-                if mercancia_data.get('MaterialPeligroso') == 'No':
-                    cartaporte_mercancia.setAttribute('MaterialPeligroso', 'No')
+                cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso', ''))
 
-                if mercancia_data.get('MaterialPeligroso') == 'Si':
+                if mercancia_data.get('MaterialPeligroso') == 'Sí':
                     cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso'))
                     cartaporte_mercancia.setAttribute('CveMaterialPeligroso', mercancia_data.get('CveMaterialPeligroso'))
                     cartaporte_mercancia.setAttribute('Embalaje', mercancia_data.get('Embalaje'))
